@@ -64,9 +64,9 @@ def runtime_error(m, parser=None, exitcode=-1):
     sys.exit(exitcode)
 
 
-class PyHocaCLI(x2go.X2goClient):
+class PyHocaCLI(x2go.X2GoClient):
     """\
-    L{PyHocaCLI} is a command-line X2Go Client wrapping around Python X2Go (C{X2goClient} class).
+    L{PyHocaCLI} is a command-line X2Go Client wrapping around Python X2Go (C{X2GoClient} class).
 
     """
     x2go_session_hash = None
@@ -88,11 +88,11 @@ class PyHocaCLI(x2go.X2goClient):
         print
         print "Available runing/suspended X2Go sessions"
         print "========================================"
-        _peername = self._X2goClient__get_session_server_peername(s_hash)
-        print "Host: %s - [%s]:%s" % (self._X2goClient__get_session_server_hostname(s_hash), _peername[0], _peername[1])
-        print "Username: %s" % self._X2goClient__get_session_username(s_hash)
+        _peername = self._X2GoClient__get_session_server_peername(s_hash)
+        print "Host: %s - [%s]:%s" % (self._X2GoClient__get_session_server_hostname(s_hash), _peername[0], _peername[1])
+        print "Username: %s" % self._X2GoClient__get_session_username(s_hash)
         print 
-        session_infos = self._X2goClient__list_sessions(s_hash)
+        session_infos = self._X2GoClient__list_sessions(s_hash)
         if session_infos:
             for session_info in session_infos.values():
                 print "Session Name: %s" % session_info
@@ -130,11 +130,11 @@ class PyHocaCLI(x2go.X2goClient):
         print
         print "X2Go desktops available for sharing"
         print "==================================="
-        _peername = self._X2goClient__get_session_server_peername(s_hash)
-        print "Host: %s - [%s]:%s" % (self._X2goClient__get_session_server_hostname(s_hash), _peername[0], _peername[1])
-        print "Username: %s" % self._X2goClient__get_session_username(s_hash)
+        _peername = self._X2GoClient__get_session_server_peername(s_hash)
+        print "Host: %s - [%s]:%s" % (self._X2GoClient__get_session_server_hostname(s_hash), _peername[0], _peername[1])
+        print "Username: %s" % self._X2GoClient__get_session_username(s_hash)
         print 
-        desktop_list = self._X2goClient__list_desktops(s_hash)
+        desktop_list = self._X2GoClient__list_desktops(s_hash)
         if desktop_list:
             for desktop_name in desktop_list:
                 print desktop_name
@@ -153,7 +153,7 @@ class PyHocaCLI(x2go.X2goClient):
         print
         print "Available X2Go session profiles"
         print "==============================="
-        _profiles = self._X2goClient__get_profiles()
+        _profiles = self._X2GoClient__get_profiles()
         for _profile_id in _profiles.profile_ids:
             _profile_config = _profiles.get_profile_config(_profile_id)
             _session_params = _profiles.to_session_params(_profile_id)
@@ -170,18 +170,18 @@ class PyHocaCLI(x2go.X2goClient):
         @type s_hash: C{str}
 
         """
-        _profiles = self._X2goClient__get_profiles()
+        _profiles = self._X2GoClient__get_profiles()
         if self.args.session_profile and _profiles.has_profile(self.args.session_profile):
             _server = _profiles.get_session_param(self.args.session_profile, 'server')
         else:
             _server = self.args.server
         # clean all sessions from X2Go server
         self.logger('cleaning up all running sessions from X2Go server: %s' % _server, loglevel=x2go.loglevel_NOTICE, )
-        self._X2goClient__clean_sessions(s_hash)
+        self._X2GoClient__clean_sessions(s_hash)
 
     def new_session(self, s_hash):
         """\
-        Launch a new X2Go session via the C{X2goSession} object with session UUID C{s_hash}.
+        Launch a new X2Go session via the C{X2GoSession} object with session UUID C{s_hash}.
 
         @param s_hash: session UUID
         @type s_hash: C{str}
@@ -193,29 +193,29 @@ class PyHocaCLI(x2go.X2goClient):
             self.logger('command for new session is: %s' % self.args.command, loglevel=x2go.loglevel_DEBUG, )
         else:
             self.logger('command from session profile to run is: %s' % self.session_registry(self.x2go_session_hash).get_session_cmd(), loglevel=x2go.loglevel_DEBUG, )
-        self._X2goClient__start_session(s_hash)
+        self._X2GoClient__start_session(s_hash)
 
     def _auto_resume_newest(self, s_hash):
-        session_infos = self._X2goClient__list_sessions(s_hash)
+        session_infos = self._X2GoClient__list_sessions(s_hash)
         if session_infos:
             newest_session_name = x2go.utils.session_names_by_timestamp(session_infos)[-1]
             self._pyhoca_logger("Resuming newest X2Go session %s..." % newest_session_name, loglevel=x2go.loglevel_NOTICE, )
-            self._X2goClient__resume_session(s_hash, newest_session_name)
+            self._X2GoClient__resume_session(s_hash, newest_session_name)
             return True
         return False
 
     def _auto_resume_oldest(self, s_hash):
-        session_infos = self._X2goClient__list_sessions(s_hash)
+        session_infos = self._X2GoClient__list_sessions(s_hash)
         if session_infos:
             oldest_session_name = x2go.utils.session_names_by_timestamp(session_infos)[0]
             self._pyhoca_logger("Resuming oldest X2Go session %s..." % oldest_session_name, loglevel=x2go.loglevel_NOTICE, )
-            self._X2goClient__resume_session(s_hash, oldest_session_name)
+            self._X2GoClient__resume_session(s_hash, oldest_session_name)
             return True
         return False
 
     def resume_session(self, s_hash):
         """\
-        Use C{X2goSession} object with session UUID C{s_hash} to resume a server-side suspended X2Go session.
+        Use C{X2GoSession} object with session UUID C{s_hash} to resume a server-side suspended X2Go session.
 
         @param s_hash: session UUID
         @type s_hash: C{str}
@@ -223,19 +223,19 @@ class PyHocaCLI(x2go.X2goClient):
         """
         # resume a running session
         self.logger('resuming X2Go session: %s' % self.args.resume, loglevel=x2go.loglevel_INFO, )
-        available_sessions = self._X2goClient__list_sessions(s_hash)
+        available_sessions = self._X2GoClient__list_sessions(s_hash)
         if available_sessions and self.args.resume == 'OLDEST':
             self._auto_resume_oldest(s_hash)
         elif available_sessions and self.args.resume == 'NEWEST':
             self._auto_resume_newest(s_hash)
         elif self.args.resume in available_sessions.keys():
-            self._X2goClient__resume_session(s_hash, self.args.resume)
+            self._X2GoClient__resume_session(s_hash, self.args.resume)
         else:
             self._runtime_error('requested session not available on X2Go server [%s]:%s' % (self.args.server, self.args.remote_ssh_port), exitcode=20)
 
     def share_desktop_session(self, s_hash):
         """\
-        Use C{X2goSession} object with session UUID C{s_hash} to share a server-side X2Go desktop session that is available for sharing.
+        Use C{X2GoSession} object with session UUID C{s_hash} to share a server-side X2Go desktop session that is available for sharing.
 
         @param s_hash: session UUID
         @type s_hash: C{str}
@@ -246,8 +246,8 @@ class PyHocaCLI(x2go.X2goClient):
         _share_mode = self.args.share_mode
         self.logger('sharing X2Go session: %s' % _desktop, loglevel=x2go.loglevel_INFO, )
         try:
-            self._X2goClient__share_desktop_session(s_hash, desktop=_desktop, share_mode=_share_mode)
-        except x2go.X2goDesktopSharingException, e:
+            self._X2GoClient__share_desktop_session(s_hash, desktop=_desktop, share_mode=_share_mode)
+        except x2go.X2GoDesktopSharingException, e:
             self._runtime_error('%s' % str(e), exitcode=54)
 
 
@@ -261,7 +261,7 @@ class PyHocaCLI(x2go.X2goClient):
         """
         # send a suspend request to a session
         self.logger('requesting X2Go session suspend of session: %s' % self.args.suspend, loglevel=x2go.loglevel_INFO, )
-        available_sessions = self._X2goClient__list_sessions(s_hash)
+        available_sessions = self._X2GoClient__list_sessions(s_hash)
 
         if self.args.suspend == "ALL":
             _session_names = available_sessions
@@ -270,7 +270,7 @@ class PyHocaCLI(x2go.X2goClient):
 
         for _session_name in _session_names:
             if _session_name in available_sessions.keys():
-                self._X2goClient__suspend_session(s_hash, _session_name)
+                self._X2GoClient__suspend_session(s_hash, _session_name)
                 self._pyhoca_logger("X2Go session %s has been suspended" % _session_name, loglevel=x2go.loglevel_NOTICE, )
             else:
                 _server = self.args.server
@@ -290,7 +290,7 @@ class PyHocaCLI(x2go.X2goClient):
         """
         # send a terminate request to a session
         self.logger('requesting X2Go session terminate of session: %s' % self.args.terminate, loglevel=x2go.loglevel_INFO, )
-        available_sessions = self._X2goClient__list_sessions(s_hash)
+        available_sessions = self._X2GoClient__list_sessions(s_hash)
 
         if self.args.terminate == "ALL":
             _session_names = available_sessions
@@ -299,7 +299,7 @@ class PyHocaCLI(x2go.X2goClient):
 
         for _session_name in _session_names:
             if _session_name in available_sessions.keys():
-                self._X2goClient__terminate_session(s_hash, _session_name)
+                self._X2GoClient__terminate_session(s_hash, _session_name)
                 self._pyhoca_logger("X2Go session %s has been terminated" % _session_name, loglevel=x2go.loglevel_NOTICE, )
             else:
                 _server = self.args.server
@@ -315,27 +315,27 @@ class PyHocaCLI(x2go.X2goClient):
 
         @param args: a class with properties representing the command-line options that are available to L{PyHocaCLI} instances.
         @type args: C{argparse.ArgumentParser} (or similar)
-        @param logger: you can pass an L{X2goLogger} object to the
+        @param logger: you can pass an L{X2GoLogger} object to the
             L{PyHocaCLI} constructor for logging application events
-        @type logger: Python X2Go C{X2goLogger} instance
-        @param liblogger: you can pass an L{X2goLogger} object to the
-            L{PyHocaCLI} constructor for logging application events, this object is forwarded to the C{X2goClient} class in Python X2Go 
-        @type liblogger: Python X2Go C{X2goLogger} instance
+        @type logger: Python X2Go C{X2GoLogger} instance
+        @param liblogger: you can pass an L{X2GoLogger} object to the
+            L{PyHocaCLI} constructor for logging application events, this object is forwarded to the C{X2GoClient} class in Python X2Go 
+        @type liblogger: Python X2Go C{X2GoLogger} instance
 
         """
         self.args = args
         if logger is None:
-            self._pyhoca_logger = x2go.X2goLogger(tag='PyHocaCLI')
+            self._pyhoca_logger = x2go.X2GoLogger(tag='PyHocaCLI')
         else:
             self._pyhoca_logger = copy.deepcopy(logger)
             self._pyhoca_logger.tag = 'PyHocaCLI'
 
-        # initialize the X2goClient context and start the connection to the X2Go server
+        # initialize the X2GoClient context and start the connection to the X2Go server
         self._pyhoca_logger('preparing requested X2Go session', loglevel=x2go.loglevel_NOTICE, )
 
-        x2go.X2goClient.__init__(self, logger=liblogger)
+        x2go.X2GoClient.__init__(self, logger=liblogger)
 
-        _profiles = self._X2goClient__get_profiles()
+        _profiles = self._X2GoClient__get_profiles()
         if self.args.session_profile and not _profiles.has_profile(self.args.session_profile):
             self._runtime_error('no such session profile of name: %s' % (self.args.session_profile), exitcode=31)
 
@@ -364,7 +364,7 @@ class PyHocaCLI(x2go.X2goClient):
                             kwargs[a] = v
 
             # setup up the session profile based X2Go session
-            self.x2go_session_hash = self._X2goClient__register_session(profile_name=self.args.session_profile,
+            self.x2go_session_hash = self._X2GoClient__register_session(profile_name=self.args.session_profile,
                                                                         known_hosts=ssh_known_hosts_filename,
                                                                         **kwargs
                                                                        )
@@ -372,7 +372,7 @@ class PyHocaCLI(x2go.X2goClient):
         else:
 
             # setup up the manually configured X2Go session
-            self.x2go_session_hash = self._X2goClient__register_session(args.server, port=int(self.args.remote_ssh_port), 
+            self.x2go_session_hash = self._X2GoClient__register_session(args.server, port=int(self.args.remote_ssh_port), 
                                                            known_hosts=ssh_known_hosts_filename,
                                                            username=self.args.username,
                                                            key_filename=self.args.ssh_privkey,
@@ -399,13 +399,13 @@ class PyHocaCLI(x2go.X2goClient):
         """
         connected = False
         force_password_auth = False
-        _username = self.args.username or self._X2goClient__get_session_username(self.x2go_session_hash)
+        _username = self.args.username or self._X2GoClient__get_session_username(self.x2go_session_hash)
         try:
 
             _auth_count = self.auth_attempts +1
             while not connected and _auth_count:
                 try:
-                    self._X2goClient__connect_session(self.x2go_session_hash, username=_username, password=self.args.password, force_password_auth=force_password_auth)
+                    self._X2GoClient__connect_session(self.x2go_session_hash, username=_username, password=self.args.password, force_password_auth=force_password_auth)
                     connected = True
                 except x2go.AuthenticationException, e:
                     force_password_auth = True
@@ -493,10 +493,10 @@ class PyHocaCLI(x2go.X2goClient):
                 time.sleep(1)
                 i+=1
 
-            if self._X2goClient__session_ok(self.x2go_session_hash):
+            if self._X2GoClient__session_ok(self.x2go_session_hash):
 
-                profile_name = self._X2goClient__get_session_profile_name(self.x2go_session_hash)
-                session_name = self._X2goClient__get_session_name(self.x2go_session_hash)
+                profile_name = self._X2GoClient__get_session_profile_name(self.x2go_session_hash)
+                session_name = self._X2GoClient__get_session_name(self.x2go_session_hash)
                 self._pyhoca_logger("X2Go session is now running, the X2Go client's profile name is: %s" % profile_name, loglevel=x2go.loglevel_INFO, )
                 self._pyhoca_logger("X2Go session name is: %s" % session_name, loglevel=x2go.loglevel_INFO, )
 
@@ -514,7 +514,7 @@ class PyHocaCLI(x2go.X2goClient):
                     session_duration = 0
                     mounted = False
 
-                    while self._X2goClient__session_ok(self.x2go_session_hash):
+                    while self._X2GoClient__session_ok(self.x2go_session_hash):
                         time.sleep(2)
                         session_duration +=2
 
@@ -522,35 +522,35 @@ class PyHocaCLI(x2go.X2goClient):
                     time.sleep(2)
 
                     # refresh session status so we can be most accurate on what we report below
-                    self._X2goClient__list_sessions(self.x2go_session_hash)
+                    self._X2GoClient__list_sessions(self.x2go_session_hash)
 
                     # report about the session status once we get here...
-                    if self._X2goClient__has_session_terminated(self.x2go_session_hash):
+                    if self._X2GoClient__has_session_terminated(self.x2go_session_hash):
                         self._pyhoca_logger("X2Go session %s has terminated" % session_name, loglevel=x2go.loglevel_NOTICE, )
-                    elif self._X2goClient__is_session_suspended(self.x2go_session_hash):
+                    elif self._X2GoClient__is_session_suspended(self.x2go_session_hash):
                         self._pyhoca_logger("X2Go session %s has been suspended" % session_name, loglevel=x2go.loglevel_NOTICE, )
-                    elif self._X2goClient__is_session_running(self.x2go_session_hash):
+                    elif self._X2GoClient__is_session_running(self.x2go_session_hash):
                         self._pyhoca_logger("X2Go session %s has been moved to a different screen" % session_name, loglevel=x2go.loglevel_NOTICE, )
 
                 except KeyboardInterrupt:
                     if self.args.share_desktop:
                         self._pyhoca_logger("Terminating X2Go shared desktop session %s" % session_name, loglevel=x2go.loglevel_INFO, )
-                        self._X2goClient__terminate_session(self.x2go_session_hash)
+                        self._X2GoClient__terminate_session(self.x2go_session_hash)
                         time.sleep(2)
                         self._pyhoca_logger("X2Go session %s has been terminated" % session_name, loglevel=x2go.loglevel_NOTICE, )
                     elif self.args.terminate_on_ctrl_c:
                         self._pyhoca_logger("Terminating X2Go session %s" % session_name, loglevel=x2go.loglevel_INFO, )
-                        self._X2goClient__terminate_session(self.x2go_session_hash)
+                        self._X2GoClient__terminate_session(self.x2go_session_hash)
                         # giving nxproxy's SSH tunnel some time to settle
                         time.sleep(2)
                         self._pyhoca_logger("X2Go session %s has been terminated" % session_name, loglevel=x2go.loglevel_NOTICE, )
                     else:
                         self._pyhoca_logger("Suspending X2Go session %s" % session_name, loglevel=x2go.loglevel_INFO, )
-                        self._X2goClient__suspend_session(self.x2go_session_hash)
+                        self._X2GoClient__suspend_session(self.x2go_session_hash)
                         # giving nxproxy's SSH tunnel some time to settle
                         time.sleep(2)
                         self._pyhoca_logger("X2Go session %s has been suspended" % session_name, loglevel=x2go.loglevel_NOTICE, )
 
-        except x2go.X2goSessionException, e:
-            self._pyhoca_logger("X2goSessionException occured:", loglevel=x2go.loglevel_ERROR)
+        except x2go.X2GoSessionException, e:
+            self._pyhoca_logger("X2GoSessionException occured:", loglevel=x2go.loglevel_ERROR)
             self._pyhoca_logger("-> %s" % str(e), loglevel=x2go.loglevel_ERROR)
